@@ -9,10 +9,10 @@ import logging
 from typing import Dict, List, Iterator, Tuple, Optional
 
 # internal
-from . import METRIC_PRIM
-from .channel_group import ChannelGroup
+from vtelem.channel.group import ChannelGroup
+from vtelem.telemetry.environment import TelemetryEnvironment
+from . import DEFAULTS
 from .state import State
-from .telemetry_environment import TelemetryEnvironment
 from .time_entity import LockEntity
 
 LOG = logging.getLogger(__name__)
@@ -64,10 +64,10 @@ class StateMachine(LockEntity):
         self.metrics: Optional[ChannelGroup] = None
         if env is not None:
             self.metrics = ChannelGroup("machine." + self.name, env)
-            self.metrics.add_channel("enter_fails", METRIC_PRIM, rate)
-            self.metrics.add_channel("exit_fails", METRIC_PRIM, rate)
-            self.metrics.add_channel("transitions", METRIC_PRIM, rate)
-            self.metrics.add_channel("iterations", METRIC_PRIM, rate)
+            self.metrics.add_channel("enter_fails", DEFAULTS["metric"], rate)
+            self.metrics.add_channel("exit_fails", DEFAULTS["metric"], rate)
+            self.metrics.add_channel("transitions", DEFAULTS["metric"], rate)
+            self.metrics.add_channel("iterations", DEFAULTS["metric"], rate)
 
     @contextmanager
     def data(self) -> Iterator[dict]:
