@@ -1,7 +1,7 @@
 # =====================================
 # generator=datazen
-# version=1.7.9
-# hash=132b6c30deef9606da5463c457ebe601
+# version=1.7.11
+# hash=ca376242c43e745908cf43cf52d2f059
 # =====================================
 """
 vtelem - Useful type definitions for working with frames.
@@ -11,6 +11,10 @@ vtelem - Useful type definitions for working with frames.
 from enum import IntEnum
 from typing import NamedTuple, Optional
 
+# internal
+from vtelem.classes.user_enum import from_enum
+from vtelem.enums.primitive import Primitive
+
 
 class FrameType(IntEnum):
     """An enumeration for possible frame types."""
@@ -25,6 +29,7 @@ class FrameType(IntEnum):
 class FrameHeader(NamedTuple):
     """Elements contained in a frame header."""
 
+    length: int
     app_id: int
     type: FrameType
     timestamp: int
@@ -43,3 +48,24 @@ class ParsedFrame(NamedTuple):
     header: FrameHeader
     body: dict
     footer: FrameFooter
+
+
+class FieldType(NamedTuple):
+    """A pairing of a field name and its type."""
+
+    name: str
+    type: Primitive
+
+
+class MessageType(IntEnum):
+    """An enumeration for possible frame types."""
+
+    AGNOSTIC = 0
+    TEXT = 1
+    JSON = 2
+    ENUM = 3
+    ENUM_REGISTRY = 4
+    PRIMITIVE = 5
+
+
+MESSAGE_TYPES = from_enum(MessageType)
